package Business::MaxMind;

use 5.006;

our $VERSION = '1.60';

1;

# ABSTRACT: API for MaxMind minFraud Services

__END__

=pod

=head1 NAME

Business::MaxMind - API for MaxMind minFraud Services

=head1 VERSION

version 1.60

=head1 DESCRIPTION

This module queries the MaxMind minFraud service and returns the results.

=head1 AUTHORS

=over 4

=item *

TJ Mather <tjmather@maxmind.com>

=item *

Frank Mather <frank@maxmind.com>

=back

=head1 CONTRIBUTORS

=for stopwords Boris Zentner Dave Rolsky Greg Oschwald Mateu X Hunter

=over 4

=item *

Boris Zentner <bzentner@maxmind.com>

=item *

Dave Rolsky <drolsky@maxmind.com>

=item *

Greg Oschwald <goschwald@maxmind.com>

=item *

Mateu X Hunter <mhunter@maxmind.com>

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2015 by MaxMind, Inc..

This is free software, licensed under:

  The GNU General Public License, Version 2, June 1991

=cut
